@@ -2,14 +2,13 @@
 #define MISSING_H
 
 #include <RcppArmadillo.h>
+#include "distfuns.h"
+#include "misc.h"
 
 void define_missingness(arma::mat& missing_indicator, arma::vec& assessor_missing,
                         const arma::mat& rankings,
                         const int& n_items, const int& n_assessors);
 
-arma::vec propose_augmentation(const arma::vec& ranks, const arma::vec& indicator,
-                               const int& n_items);
-
 void initialize_missing_ranks(arma::mat& rankings, const arma::mat& missing_indicator,
                               const arma::vec& assessor_missing,
                               const int& n_items, const int& n_assessors);
